@@ -49,8 +49,10 @@ validMizerParams <- function(object) {
         errors <- c(errors, msg)
     }
     # Check w_min_idx
-    if (any(object@species_params$w_min < object@w[object@w_min_idx]) ||
-        any(object@species_params$w_min > object@w[object@w_min_idx + 1])) {
+    if (any(object@species_params$w_min + .Machine$double.eps <
+            object@w[object@w_min_idx]) ||
+        any(object@species_params$w_min - .Machine$double.eps >
+            object@w[object@w_min_idx + 1])) {
         msg <- "The `w_min_idx` should point to the start of the size bin containing the egg size `w_min`."
         errors <- c(errors, msg)
     }
